@@ -2,9 +2,7 @@ use v6;
 
 # css3 - css21 base properties + css3 extensions
 # link: http://www.w3.org/TR/2011/NOTE-css-2010-20110512/#css3
-grammar CSS::Module::CSS3:ver<2010-20110512.000> {...};
-class   CSS::Module::CSS3::Actions {...};
-
+use CSS::Module;
 use CSS::Module::CSS21::Actions;
 use CSS::Module::CSS21;
 
@@ -26,10 +24,10 @@ class CSS::Module::CSS3::Actions
     is CSS::Module::CSS3::PagedMedia::Actions
     is CSS::Module::CSS3::Selectors::Actions
     is CSS::ModuleX::CSS21::Actions
-    is CSS::Module::CSS3::_Base::Actions
-{};
+    is CSS::Module::CSS3::_Base::Actions {
+};
 
-grammar CSS::Module::CSS3
+grammar CSS::Module::CSS3:ver<0.0..1> #:api<2010-20110512>
     is CSS::Module::CSS3::Colors
     is CSS::Module::CSS3::Fonts
     is CSS::Module::CSS3::MediaQueries
@@ -37,6 +35,22 @@ grammar CSS::Module::CSS3
     is CSS::Module::CSS3::PagedMedia
     is CSS::Module::CSS3::Selectors
     is CSS::ModuleX::CSS21
-    is CSS::Module::CSS3::_Base
-{};
+    is CSS::Module::CSS3::_Base {
+
+    method module {
+        require CSS::Module::CSS3::Metadata;
+        require CSS::Module::CSS3::Fonts::AtFontFace;
+        my %sub-module = '@font-face' => ::('CSS::Module::CSS3::Fonts::AtFontFace').module;
+        my %property-metadata = %$CSS::Module::CSS3::Metadata::property;
+        my $actions = CSS::Module::CSS3::Actions;
+        state $this //= CSS::Module.new(
+            :name<CSS3>,
+            :grammar($?CLASS),
+	    :$actions,
+	    :%property-metadata,
+            :%sub-module,
+	    );
+    }
+
+};
 
